==> nextcloud-app-news-1:25.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/sv.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Förfrågan misslyckades, nätverksanslutning otillgänglig!",
    "Request unauthorized. Are you logged in?" : "Ogiltig begäran. Är du inloggad?",
    "Request forbidden. Are you an administrator?" : "Förfrågan förbjuden. Är du administratör?",
    "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
    "News feeds" : "Nyhetsflöden",
    "Unread articles" : "Olästa artiklar",
    "News" : "Nyheter",
    "News folders" : "Nyhetsmappar",
    "News articles" : "Nyhetsartiklar",
    "Shared with me" : "Delad med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
    "Download" : "Hämta",
    "Close" : "Stäng",
    "Internal server error!" : "Internt serverfel!",
    "Unknown error!" : "Okänt fel!",
    "Web address" : "Webbadress",
    "Please check your data/nextcloud.log file for additional information!" : "Kontrollera din data/nextcloud.log-fil för ytterligare information!",
    "No folder" : "Ingen mapp",
    "Folder name" : "Mappnamn",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Feed exists already!" : "Flödet finns redan!",
    "New folder" : "Ny mapp",
    "Folder exists already!" : "Katalogen finns redan",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundläggande HTTP-autentiseringsuppgifter måste lagras okrypterade! Alla med åtkomst till servern eller databasen kommer att kunna få åtkomst till dem!",
    "Credentials" : "Inloggningsuppgifter",
    "Auto discover Feed" : "Upptäck flöde automatiskt",
    "Subscribe" : "Prenumerera",
    "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
    "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
    "Last job execution ran {relativeTime}. Something seems wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något verkar vara fel.",
    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
    "Maximum read count per feed" : "Maximalt läsantal per flöde",
    "Maximum redirects" : "Maximala omdirigeringar",
    "Feed fetcher timeout" : "Timeout för flödes-hämtare",
    "Explore Service URL" : "Utforska tjänstwebbadress",
    "Update interval" : "Uppdateringsintervall",
    "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
    "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definierar den maximala mängden artiklar som kan läsas per flöde som inte kommer att raderas av rensningsjobbet; om gamla artiklar dyker upp igen efter att ha lästs, öka detta värde; negativa värden som -1 kommer att stänga av denna funktion.",
    "Delete unread articles automatically" : "Radera olästa artiklar automatiskt",
    "Enable this if you also want to delete unread articles." : "Aktivera detta om du också vill ta bort olästa artiklar.",
    "How many redirects the feed fetcher should follow." : "Hur många omdirigeringar flödet skall tillåtas följa.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
    "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
    "Use next update time for feed updates" : "Använd nästa uppdateringstid för flödesuppdateringar",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktivera detta för att använda den beräknade nästa uppdateringstiden för flödesuppdateringar. Inaktivera för att uppdatera flöden baserat enbart på uppdateringsintervallet.",
    "Article list" : "Artikellista",
    "Article details" : "Artikeldetaljer",
    "No article selected" : "Ingen artikel har valts",
    "Please select an article from the list..." : "Välj en artikel från listan...",
    "Move" : "Flytta",
    "User Name" : "Användarnamn",
    "Share" : "Dela",
    "Share with" : "Dela med",
    "Share with {num} users" : "Dela med {num} användare",
    "Default" : "Förvald",
    "Compact" : "Kompakt",
    "Screenreader" : "Skärmläsare",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horisontell",
    "Off" : "Av",
    "Please select a valid OPML file" : "Välj en giltig OPML-fil",
    "File successfully uploaded" : "Filen har laddats upp",
    "Error uploading the opml file" : "Fel vid uppladdning av opml-filen",
    "Error connecting to the server" : "Fel vid anslutning till servern",
    "Error retrieving the opml file" : "Det gick inte att hämta opml-filen",
    "Rename Folder" : "Byt namn på mapp",
    "Are you sure you want to delete?" : "Är du säker på att du vill ta bort?",
    "Mark read" : "Markera som läst",
    "All articles" : "Alla artiklar",
    "Starred" : "Stjärnmärkt",
    "Has feeds with errors!" : "Har flöden med fel!",
    "Explore" : "Utforska",
    "Settings" : "Inställningar",
    "Documentation" : "Dokumentation",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Article feed information" : "Artikelflödesinformation",
    "Display mode" : "Visningsläge",
    "Split mode" : "Delat läge",
    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
    "Show all articles" : "Visa alla artiklar",
    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
    "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
    "Abonnements (OPML)" : "Prenumerationer (OPML)",
    "Rename" : "Byt namn",
    "Delete" : "Ta bort",
    "Rename Feed" : "Döp om Feed",
    "Open Feed URL" : "Öppna flödes-URL",
    "Unpin from top" : "Ta bort från toppen",
    "Pin to top" : "Fäst i toppen",
    "Newest first" : "Nyaste först",
    "Oldest first" : "Äldst först",
    "Default order" : "Standardordning",
    "Enable full text" : "Aktivera fulltext",
    "Disable full text" : "Avaktivera fulltext",
    "Unread updated" : "Markera som oläst",
    "Ignore updated" : "Ignorera uppdaterad",
    "Previous Item" : "Föregående objekt",
    "Previous" : "Föregående",
    "Next Item" : "Nästa objekt",
    "Next" : "Nästa",
    "Share within Instance" : "Dela inom instans",
    "Toggle star article" : "Växla stjärnmärkning av artiklar",
    "Mark unread" : "Markera som oläst",
    "Close details" : "Stäng detaljer",
    "by" : "av",
    "from" : "från",
    "shared by" : "delad av",
    "Play audio" : "Spela ljud",
    "Download audio" : "Hämta ljud",
    "Download video" : "Hämta video",
    "{num} seconds" : "{num} sekunder",
    "{num} minutes ago" : "{num} minuter sedan",
    "{num} hours ago" : "{num} timmar sedan",
    "{num} days ago" : "{num} dagar sedan",
    "{num} months ago" : "{num} månader sedan",
    "{num} years ago" : "{num} år sedan",
    "Open website" : "Öppna webbplats",
    "Keep article unread" : "Behåll artikel oläst",
    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
    "Remove keep article unread" : "Ta bort behåll artikel oläst",
    "Not available" : "Inte tillgänglig",
    "Last update" : "Senaste uppdatering",
    "Time when the feed was last downloaded" : "Tidpunkt då flödet senast laddades ned",
    "Next update" : "Nästa uppdatering",
    "Time when the next feed update will be done" : "Tidpunkt då nästa flödesuppdatering kommer att göras",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Endast om det är aktiverat i admininställningarna, annars används det vanliga uppdateringsintervallet",
    "Articles per update" : "Artiklar per uppdatering",
    "Maximum number of articles reached in a feed update" : "Maximalt antal artiklar nådda i en flödesuppdatering",
    "Error Count" : "Antal fel",
    "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
    "Title" : "Titel",
    "Keyboard shortcut" : "Tangentbordsgenvägar",
    "Action" : "Ågärd",
    "Jump to next article" : "Hoppa till nästa artikel",
    "(screenreader mode)" : "(skärmläsarläge)",
    "Jump to previous article" : "Hoppa till föregående artikel",
    "right" : "Höger",
    "left" : "vänster",
    "Star article and jump to next one" : "Stärnmärk artikel och hoppa till nästa",
    "Open article in new tab" : "Öppna artikeln i ny flik",
    "Show article details in compact view" : "Visa artikeldetaljer i kompakt vy",
    "Close article details in compact view" : "Stäng artikeldetaljer i kompakt vy",
    "Refresh" : "Uppdatera",
    "Load next feed" : "Läs in nästkommande flöde",
    "Load previous feed" : "Läs in föregående flöde",
    "Load previous folder" : "Läs in föregående mapp",
    "Load next folder" : "Läs in nästkommande mapp",
    "Scroll to active navigation entry" : "Skrolla till aktiv navigations-post",
    "Shift" : "Shift",
    "Mark current articles feed/folder as read" : "Markera aktuellt artikelflöde/mapp som läst",
    "All Articles" : "Alla artiklar",
    "No feeds found to add" : "Inga flöden hittades att lägga till",
    "Subscribe to" : "Prenumerera på",
    "Unread Articles" : "Olästa artiklar",
    "If given, this service" : "Om den ges, denna tjänst",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
    "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API",
    "No articles available" : "Inga artiklar tillgängliga",
    "No unread articles available" : "Inga olästa artiklar tillgängliga",
    "Star article" : "Stjärnmärk artikel",
    "Unstar article" : "Ta bort stjärnmärke på artikel",
    "Share with users" : "Dela med användare",
    "No users found" : "Inga användare hittades",
    "Error while searching for users" : "Kunde inte söka bland användare",
    "Share on social media" : "Dela via sociala medier",
    "I wanted you to see this article" : "Jag vill rekommendera dig den här artikeln",
    "Check out this article" : "Spana in den här artikeln",
    "Description" : "Beskrivning",
    "Toggle expand article in compact view" : "Aktivera för att expandera artikeln i kompakt vy",
    "Mark current article's feed/folder read" : "Markera nuvarande artikels flöde/mapp som läst",
    "Folder" : "Mapp",
    "Go back" : "Gå tillbaks",
    "New Folder" : "Ny mapp",
    "Create" : "Skapa",
    "Update failed more than 50 times" : "Uppdatering misslyckades mer än 50 gånger",
    "Deleted feed" : "Borttagna flöde",
    "Undo delete feed" : "Ångra radera flöde",
    "Menu" : "Meny",
    "Open feed URL" : "Öppna flödeswebbadress",
    "Dismiss" : "Avfärda",
    "Collapse" : "Dölj",
    "Deleted folder" : "Raderad mapp",
    "Undo delete folder" : "Ångra radera mapp",
    "Compact view" : "Kompakt vy",
    "Expand articles on key navigation" : "Expandera artiklar vid hantering",
    "Subscriptions (OPML)" : "Abonnemang (OPML)",
    "Import" : "Importera",
    "Export" : "Exportera",
    "Error when importing: File does not contain valid OPML" : "Fel vid importering: Fil innehåller inte giltig OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fel vid import: OPML innehåller varken flöden eller mappar",
    "Unread/Starred Articles" : "Olästa/Stjärnmärkta artiklar",
    "Error when importing: file does not contain valid JSON" : "Fel vid import: filen innehåller inte giltig JSON",
    "Help" : "Hjälp",
    "Report a bug" : "Rapportera ett problem"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1:26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/sv.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Nyhetsflöden",
    "Unread articles" : "Olästa artiklar",
    "News" : "Nyheter",
    "News folders" : "Nyhetsmappar",
    "News articles" : "Nyhetsartiklar",
    "Shared with me" : "Delad med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
    "Download" : "Hämta",
    "Close" : "Stäng",
    "Internal server error!" : "Internt serverfel!",
    "Unknown error!" : "Okänt fel!",
    "Web address" : "Webbadress",
    "Please check your data/nextcloud.log file for additional information!" : "Kontrollera din data/nextcloud.log-fil för ytterligare information!",
    "No folder" : "Ingen mapp",
    "Folder name" : "Mappnamn",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Feed exists already!" : "Flödet finns redan!",
    "New folder" : "Ny mapp",
    "Folder exists already!" : "Katalogen finns redan",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundläggande HTTP-autentiseringsuppgifter måste lagras okrypterade! Alla med åtkomst till servern eller databasen kommer att kunna få åtkomst till dem!",
    "Credentials" : "Inloggningsuppgifter",
    "Auto discover Feed" : "Upptäck flöde automatiskt",
    "Subscribe" : "Prenumerera",
    "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
    "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
    "Last job execution ran {relativeTime}. Something seems wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något verkar vara fel.",
    "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
    "Maximum read count per feed" : "Maximalt läsantal per flöde",
    "Maximum redirects" : "Maximala omdirigeringar",
    "Feed fetcher timeout" : "Timeout för flödes-hämtare",
    "Explore Service URL" : "Utforska tjänstwebbadress",
    "Update interval" : "Uppdateringsintervall",
    "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
    "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definierar den maximala mängden artiklar som kan läsas per flöde som inte kommer att raderas av rensningsjobbet; om gamla artiklar dyker upp igen efter att ha lästs, öka detta värde; negativa värden som -1 kommer att stänga av denna funktion.",
    "Delete unread articles automatically" : "Radera olästa artiklar automatiskt",
    "Enable this if you also want to delete unread articles." : "Aktivera detta om du också vill ta bort olästa artiklar.",
    "How many redirects the feed fetcher should follow." : "Hur många omdirigeringar flödet skall tillåtas följa.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
    "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
    "Use next update time for feed updates" : "Använd nästa uppdateringstid för flödesuppdateringar",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktivera detta för att använda den beräknade nästa uppdateringstiden för flödesuppdateringar. Inaktivera för att uppdatera flöden baserat enbart på uppdateringsintervallet.",
    "Article list" : "Artikellista",
    "Article details" : "Artikeldetaljer",
    "No article selected" : "Ingen artikel har valts",
    "Please select an article from the list..." : "Välj en artikel från listan...",
    "Move" : "Flytta",
    "User Name" : "Användarnamn",
    "Share" : "Dela",
    "Share with" : "Dela med",
    "Share with {num} users" : "Dela med {num} användare",
    "Default" : "Förvald",
    "Compact" : "Kompakt",
    "Screenreader" : "Skärmläsare",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horisontell",
    "Off" : "Av",
    "Please select a valid OPML file" : "Välj en giltig OPML-fil",
    "File successfully uploaded" : "Filen har laddats upp",
    "Error uploading the opml file" : "Fel vid uppladdning av opml-filen",
    "Error connecting to the server" : "Fel vid anslutning till servern",
    "Error retrieving the opml file" : "Det gick inte att hämta opml-filen",
    "Rename Folder" : "Byt namn på mapp",
    "Are you sure you want to delete?" : "Är du säker på att du vill ta bort?",
    "Mark read" : "Markera som läst",
    "All articles" : "Alla artiklar",
    "Starred" : "Stjärnmärkt",
    "Has feeds with errors!" : "Har flöden med fel!",
    "Explore" : "Utforska",
    "Settings" : "Inställningar",
    "Documentation" : "Dokumentation",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Article feed information" : "Artikelflödesinformation",
    "Display mode" : "Visningsläge",
    "Split mode" : "Delat läge",
    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
    "Show all articles" : "Visa alla artiklar",
    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
    "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
    "Abonnements (OPML)" : "Prenumerationer (OPML)",
    "Rename" : "Byt namn",
    "Delete" : "Ta bort",
    "Rename Feed" : "Döp om Feed",
    "Open Feed URL" : "Öppna flödes-URL",
    "Unpin from top" : "Ta bort från toppen",
    "Pin to top" : "Fäst i toppen",
    "Newest first" : "Nyaste först",
    "Oldest first" : "Äldst först",
    "Default order" : "Standardordning",
    "Enable full text" : "Aktivera fulltext",
    "Disable full text" : "Avaktivera fulltext",
    "Mark as unread on update" : "Markera som oläst vid uppdatering",
    "Keep read status on update" : "Behåll lässtatus vid uppdatering",
    "Previous Item" : "Föregående objekt",
    "Previous" : "Föregående",
    "Next Item" : "Nästa objekt",
    "Next" : "Nästa",
    "Share within Instance" : "Dela inom instans",
    "Toggle star article" : "Växla stjärnmärkning av artiklar",
    "Mark unread" : "Markera som oläst",
    "Close details" : "Stäng detaljer",
    "shared by" : "delad av",
    "by" : "av",
    "Play audio" : "Spela ljud",
    "Download audio" : "Hämta ljud",
    "Download video" : "Hämta video",
    "Open website" : "Öppna webbplats",
    "Keep article unread" : "Behåll artikel oläst",
    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
    "Remove keep article unread" : "Ta bort behåll artikel oläst",
    "Not available" : "Inte tillgänglig",
    "Importing feeds" : "Importerar flöden",
    "Please wait" : "Vänligen vänta",
    "Last update" : "Senaste uppdatering",
    "Time when the feed was last downloaded" : "Tidpunkt då flödet senast laddades ned",
    "Next update" : "Nästa uppdatering",
    "Time when the next feed update will be done" : "Tidpunkt då nästa flödesuppdatering kommer att göras",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Endast om det är aktiverat i admininställningarna, annars används det vanliga uppdateringsintervallet",
    "Articles per update" : "Artiklar per uppdatering",
    "Maximum number of articles reached in a feed update" : "Maximalt antal artiklar nådda i en flödesuppdatering",
    "Error Count" : "Antal fel",
    "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
    "Title" : "Titel",
    "Keyboard shortcut" : "Tangentbordsgenvägar",
    "Action" : "Ågärd",
    "Jump to next article" : "Hoppa till nästa artikel",
    "(screenreader mode)" : "(skärmläsarläge)",
    "Jump to previous article" : "Hoppa till föregående artikel",
    "right" : "Höger",
    "left" : "vänster",
    "Star article and jump to next one" : "Stärnmärk artikel och hoppa till nästa",
    "Open article in new tab" : "Öppna artikeln i ny flik",
    "Show article details in compact view" : "Visa artikeldetaljer i kompakt vy",
    "Close article details in compact view" : "Stäng artikeldetaljer i kompakt vy",
    "Refresh" : "Uppdatera",
    "Load next feed" : "Läs in nästkommande flöde",
    "Load previous feed" : "Läs in föregående flöde",
    "Load previous folder" : "Läs in föregående mapp",
    "Load next folder" : "Läs in nästkommande mapp",
    "Scroll to active navigation entry" : "Skrolla till aktiv navigations-post",
    "Shift" : "Shift",
    "Mark current articles feed/folder as read" : "Markera aktuellt artikelflöde/mapp som läst",
    "All Articles" : "Alla artiklar",
    "No feeds found to add" : "Inga flöden hittades att lägga till",
    "Subscribe to" : "Prenumerera på",
    "Unread Articles" : "Olästa artiklar",
    "If given, this service" : "Om den ges, denna tjänst",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
    "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API"
},
"nplurals=2; plural=(n != 1);");
